Module array

Module array 

Structs

WuiArray
A generic array structure for FFI, representing a contiguous sequence of elements. WuiArray can represent multiple types of arrays, for instance, a &[T] (in this case, the lifetime of WuiArray is bound to the caller’s scope), or a value type having a static lifetime like Vec<T>, Box<[T]>, Bytes, or even a foreign allocated array. For a value type, WuiArray contains a destructor function pointer to free the array buffer, whatever it is allocated by Rust side or foreign side. We assume T does not contain any non-trivial drop logic, and WuiArray will not call drop on each element when it is dropped.
WuiArraySlice
WuiArrayVTable

Type Aliases

WuiData
A type alias representing binary data as a byte array.