Structs
- WuiArray
- A generic array structure for FFI, representing a contiguous sequence of elements.
WuiArraycan represent multiple types of arrays, for instance, a&[T](in this case, the lifetime of WuiArray is bound to the caller’s scope), or a value type having a static lifetime likeVec<T>,Box<[T]>,Bytes, or even a foreign allocated array. For a value type,WuiArraycontains a destructor function pointer to free the array buffer, whatever it is allocated by Rust side or foreign side. We assumeTdoes not contain any non-trivial drop logic, andWuiArraywill not calldropon each element when it is dropped. - WuiArray
Slice - WuiArrayV
Table
Type Aliases
- WuiData
- A type alias representing binary data as a byte array.